@@ -1739,17 +1739,34 @@ class HalfEdge(Datastructure):
         return not any(4 != len(self.face_vertices(fkey)) for fkey in self.faces())
 
     def is_empty(self):
-        """Boolean whether the mesh is empty.
+        """Verify that the mesh is empty.
 
         Returns
         -------
         bool
-            True if no vertices. False otherwise.
+            True if the mesh has no vertices.
+            False otherwise.
         """
         if self.number_of_vertices() == 0:
             return True
         return False
 
+    def is_closed(self):
+        """Verify that the mesh is closed.
+
+        Returns
+        -------
+        bool
+            True if the mesh is not empty and has no naked edges.
+            False otherwise.
+        """
+        if self.is_empty():
+            return False
+        for edge in self.edges():
+            if self.is_edge_on_boundary(*edge):
+                return False
+        return True
+
     def euler(self):
         """Calculate the Euler characteristic.
 
